======================
backports.test.support
======================

This backports Python 3's `test.support`_ package under the backports_ namespace.

This is probably only interesting if you're backporting standard library test code.

.. _test.support: https://docs.python.org/3.6/library/test.html#module-test.support
.. _backports: https://pypi.python.org/pypi/backports

.. image:: https://img.shields.io/pypi/v/backports.test.support.svg
    :target: https://pypi.python.org/pypi/backports.test.support

.. image:: https://img.shields.io/badge/source-GitHub-lightgrey.svg
    :target: https://github.com/pjdelport/backports.test.support

.. image:: https://img.shields.io/github/issues/pjdelport/backports.test.support.svg
    :target: https://github.com/pjdelport/backports.test.support/issues?q=is:open

.. image:: https://travis-ci.org/pjdelport/backports.test.support.svg?branch=master
    :target: https://travis-ci.org/pjdelport/backports.test.support

.. image:: https://codecov.io/github/pjdelport/backports.test.support/coverage.svg?branch=master
    :target: https://codecov.io/github/pjdelport/backports.test.support?branch=master


Supported Python versions
=========================

* CPython: 2.7, 3.4, 3.5, 3.6
* PyPy, PyPy3
